%bcond tests 1

# Use this to package a pre-release
#global commit xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
#global snapdate yyyymmdd

Name:           hatch
Version:        1.9.0%{?commit:^%{snapdate}git%(c='%{commit}'; echo "${c:0:7}")}
Release:        %autorelease
Summary:        A modern project, package, and virtual env manager

%global tag hatch-v%{version}
%global ref %{?commit:%{commit}}%{?!commit:%{tag}}
%global archivename hatch-%{ref}

# The entire source is (SPDX) MIT. Apache-2.0 license text in the tests is used
# as a sample license text, not as a license for the source.
License:        MIT
URL:            https://github.com/pypa/hatch
Source0:        %{url}/archive/%{ref}/%{archivename}.tar.gz
# For now, we need a helper script to access environments defined with
# hatch/hatchling (https://hatch.pypa.io/latest/config/environment/).
Source1:        extract-hatchling-environments

# Written for Fedora in groff_man(7) format based on --help output
Source100:      hatch.1
Source200:      hatch-build.1
Source300:      hatch-clean.1
Source400:      hatch-config.1
Source410:      hatch-config-explore.1
Source420:      hatch-config-find.1
Source430:      hatch-config-restore.1
Source440:      hatch-config-set.1
Source450:      hatch-config-show.1
Source460:      hatch-config-update.1
Source500:      hatch-dep.1
Source510:      hatch-dep-hash.1
Source520:      hatch-dep-show.1
Source521:      hatch-dep-show-requirements.1
Source522:      hatch-dep-show-table.1
Source600:      hatch-env.1
Source610:      hatch-env-create.1
Source620:      hatch-env-find.1
Source630:      hatch-env-prune.1
Source640:      hatch-env-remove.1
Source650:      hatch-env-run.1
Source660:      hatch-env-show.1
Source700:      hatch-new.1
Source800:      hatch-project.1
Source810:      hatch-project-metadata.1
Source900:      hatch-publish.1
Source1000:     hatch-run.1
Source1100:     hatch-shell.1
Source1200:     hatch-status.1
Source1300:     hatch-version.1
Source1400:     hatch-fmt.1
Source1500:     hatch-python.1
Source1510:     hatch-python-find.1
Source1520:     hatch-python-install.1
Source1530:     hatch-python-remove.1
Source1540:     hatch-python-show.1
Source1550:     hatch-python-update.1

# Add the requires_internet mark to a few tests
# https://github.com/pypa/hatch/pull/1167
Patch:          %{url}/pull/1167.patch

BuildArch:      noarch

BuildRequires:  python3-devel

%if %{with tests}
# As of 1.8.0, a number of tests in TestBuildBootstrap require cargo.
BuildRequires:  cargo
%endif

BuildRequires:  git-core
Requires:       git-core

%description
Hatch is a modern, extensible Python project manager.

Features:

  • Standardized build system with reproducible builds by default
  • Robust environment management with support for custom scripts
  • Easy publishing to PyPI or other sources
  • Version management
  • Configurable project generation with sane defaults
  • Responsive CLI, ~2-3x faster than equivalent tools


%prep
%autosetup -n %{archivename} -p1

# Extract environment dependencies from hatch.toml
'%{SOURCE1}' -v
# https://docs.fedoraproject.org/en-US/packaging-guidelines/Python/#_linters
sed -r -i 's/^pytest-cov/# &/' _req/env.test.txt


%generate_buildrequires
%pyproject_buildrequires %{?with_tests:_req/env.test.txt}


%build
%pyproject_wheel

# The Markdown documentation is meant to be built with mkdocs. The HTML result
# is unsuitable for packaging due to various bundled and pre-minified
# JavaScript and CSS. See https://bugzilla.redhat.com/show_bug.cgi?id=2006555
# for discussion of similar problems with Sphinx and Doxygen. We therefore do
# not build or install the documentation.


%install
%pyproject_install
%pyproject_save_files -l hatch

install -t '%{buildroot}%{_mandir}/man1' -D -p -m 0644 \
    '%{SOURCE100}' \
    '%{SOURCE200}' \
    '%{SOURCE300}' \
    '%{SOURCE400}' '%{SOURCE410}' '%{SOURCE420}' '%{SOURCE430}' \
      '%{SOURCE440}' '%{SOURCE450}' '%{SOURCE460}' \
    '%{SOURCE500}' '%{SOURCE510}' '%{SOURCE520}' '%{SOURCE521}' \
      '%{SOURCE522}' \
    '%{SOURCE600}' '%{SOURCE610}' '%{SOURCE620}' '%{SOURCE630}' \
      '%{SOURCE640}' '%{SOURCE650}' '%{SOURCE660}' \
    '%{SOURCE700}' \
    '%{SOURCE800}' '%{SOURCE810}' \
    '%{SOURCE900}' \
    '%{SOURCE1000}' \
    '%{SOURCE1100}' \
    '%{SOURCE1200}' \
    '%{SOURCE1300}' \
    '%{SOURCE1400}' \
    '%{SOURCE1500}' '%{SOURCE1510}' '%{SOURCE1520}' '%{SOURCE1530}' \
      '%{SOURCE1540}' '%{SOURCE1550}'


%check
%if %{with tests}
# There is no need to deselect mark “requires_internet” manually because it
# happens automagically via a runtime connectivity check.

# TODO: What is  happening here?
# >           assert zip_info.date_time == (2020, 2, 2, 0, 0, 0)
# E           assert (2022, 5, 18, 0, 0, 0) == (2020, 2, 2, 0, 0, 0)
# E             At index 0 diff: 2022 != 2020
# E             Full diff:
# E             - (2020, 2, 2, 0, 0, 0)
# E             + (2022, 5, 18, 0, 0, 0)
k="${k-}${k+ and }not (TestBuildStandard and test_editable_)"
k="${k-}${k+ and }not (TestBuildStandard and test_default_auto_detection)"
k="${k-}${k+ and }not test_explicit_path"
k="${k-}${k+ and }not test_default"

%ifnarch x86_64
# Several tests related to Python distributions fail on Fedora Linux on
# non-x86_64 architectures
# https://github.com/pypa/hatch/issues/1145
k="${k-}${k+ and }not (TestGetInstalled and test_order)"
k="${k-}${k+ and }not test_variants[linux-"
%endif

%pytest -k "${k-}" -vv
%else
%pyproject_check_import
%endif


%files -f %{pyproject_files}
%{_bindir}/hatch
%{_mandir}/man1/hatch.1*
%{_mandir}/man1/hatch-*.1*


%changelog
%autochangelog
